public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
* [PATCH] MdePkg: Fix some typing errors
@ 2016-09-09 20:33 Thomas Huth
  2016-09-12  1:26 ` Gao, Liming
  2016-09-12  9:09 ` Gao, Liming
  0 siblings, 2 replies; 5+ messages in thread
From: Thomas Huth @ 2016-09-09 20:33 UTC (permalink / raw)
  To: edk2-devel; +Cc: Michael D Kinney, Liming Gao

Correct the typos in some files of MdePkg.

Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Thomas Huth <thuth@redhat.com>
---
 .../BaseExtractGuidedSectionLib.c                    |  6 +++---
 MdePkg/Library/BaseLib/String.c                      |  2 +-
 MdePkg/Library/UefiFileHandleLib/UefiFileHandleLib.c | 20 ++++++++++----------
 MdePkg/Library/UefiUsbLib/UsbDxeLib.c                |  2 +-
 4 files changed, 15 insertions(+), 15 deletions(-)

diff --git a/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c b/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c
index 3a12cb1..28996f3 100644
--- a/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c
+++ b/MdePkg/Library/BaseExtractGuidedSectionLib/BaseExtractGuidedSectionLib.c
@@ -175,7 +175,7 @@ ExtractGuidedSectionRegisterHandlers (
   EXTRACT_GUIDED_SECTION_HANDLER_INFO *HandlerInfo;
 
   //
-  // Check input paramter
+  // Check input parameter
   //
   ASSERT (SectionGuid != NULL);
   ASSERT (GetInfoHandler != NULL);
@@ -270,7 +270,7 @@ ExtractGuidedSectionGetInfo (
   EFI_GUID                            *SectionDefinitionGuid;
   
   //
-  // Check input paramter
+  // Check input parameter
   //
   ASSERT (InputSection != NULL);
   ASSERT (OutputBufferSize != NULL);
@@ -449,7 +449,7 @@ ExtractGuidedSectionGetHandlers (
   EXTRACT_GUIDED_SECTION_HANDLER_INFO *HandlerInfo;
 
   //
-  // Check input paramter
+  // Check input parameter
   //
   ASSERT (SectionGuid != NULL);
 
diff --git a/MdePkg/Library/BaseLib/String.c b/MdePkg/Library/BaseLib/String.c
index 07c0562..25962f8 100644
--- a/MdePkg/Library/BaseLib/String.c
+++ b/MdePkg/Library/BaseLib/String.c
@@ -1,5 +1,5 @@
 /** @file
-  Unicode and ASCII string primatives.
+  Unicode and ASCII string primitives.
 
   Copyright (c) 2006 - 2014, Intel Corporation. All rights reserved.<BR>
   This program and the accompanying materials
diff --git a/MdePkg/Library/UefiUsbLib/UsbDxeLib.c b/MdePkg/Library/UefiUsbLib/UsbDxeLib.c
index b22a829..b1fcbc5 100644
--- a/MdePkg/Library/UefiUsbLib/UsbDxeLib.c
+++ b/MdePkg/Library/UefiUsbLib/UsbDxeLib.c
@@ -628,7 +628,7 @@ UsbClearEndpointHalt (
 
   ZeroMem (&EndpointDescriptor, sizeof (EFI_USB_ENDPOINT_DESCRIPTOR));
   //
-  // First seach the endpoint descriptor for that endpoint addr
+  // First search the endpoint descriptor for that endpoint addr
   //
   Result = UsbIo->UsbGetInterfaceDescriptor (
                     UsbIo,
diff --git a/MdePkg/Library/UefiFileHandleLib/UefiFileHandleLib.c b/MdePkg/Library/UefiFileHandleLib/UefiFileHandleLib.c
index 8f3cde0..daed0f4 100644
--- a/MdePkg/Library/UefiFileHandleLib/UefiFileHandleLib.c
+++ b/MdePkg/Library/UefiFileHandleLib/UefiFileHandleLib.c
@@ -231,7 +231,7 @@ FileHandleWrite(
 
 @param FileHandle               the file handle to close.
 
-@retval EFI_SUCCESS             the file handle was closed sucessfully.
+@retval EFI_SUCCESS             the file handle was closed successfully.
 **/
 EFI_STATUS
 EFIAPI
@@ -261,7 +261,7 @@ FileHandleClose (
 
   @param FileHandle             the file handle to delete
 
-  @retval EFI_SUCCESS           the file was closed sucessfully
+  @retval EFI_SUCCESS           the file was closed successfully
   @retval EFI_WARN_DELETE_FAILURE the handle was closed, but the file was not
                                 deleted
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
@@ -297,9 +297,9 @@ FileHandleDelete (
   has the effect of starting the read process of the directory entries over.
 
   @param FileHandle             The file handle on which the position is being set
-  @param Position               Byte position from begining of file
+  @param Position               Byte position from beginning of file
 
-  @retval EFI_SUCCESS           Operation completed sucessfully.
+  @retval EFI_SUCCESS           Operation completed successfully.
   @retval EFI_UNSUPPORTED       the seek request for non-zero is not valid on
                                 directories.
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
@@ -330,9 +330,9 @@ FileHandleSetPosition (
   if FileHandle is a directory.
 
   @param FileHandle             The open file handle on which to get the position.
-  @param Position               Byte position from begining of file.
+  @param Position               Byte position from beginning of file.
 
-  @retval EFI_SUCCESS           the operation completed sucessfully.
+  @retval EFI_SUCCESS           the operation completed successfully.
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
   @retval EFI_UNSUPPORTED       the request is not valid on directories.
 **/
@@ -489,7 +489,7 @@ FileHandleFindFirstFile (
   }
 
   //
   // reset to the begining of the directory
   //
   Status = FileHandleSetPosition(DirHandle, 0);
   if (EFI_ERROR(Status)) {
@@ -581,7 +581,7 @@ FileHandleFindNextFile(
   @param[in] FileHandle         The file handle from which size is retrieved.
   @param[out] Size              The pointer to size.
 
-  @retval EFI_SUCCESS           Operation was completed sucessfully.
+  @retval EFI_SUCCESS           Operation was completed successfully.
   @retval EFI_DEVICE_ERROR      Cannot access the file.
   @retval EFI_INVALID_PARAMETER FileHandle is NULL.
                                 Size is NULL.
@@ -821,7 +821,7 @@ FileHandleGetFileName (
         break;
       } else {
         //
-        // We got info... do we have a name? if yes preceed the current path with it...
+        // We got info... do we have a name? if yes precede the current path with it...
         //
         if (StrLen (FileInfo->FileName) == 0) {
           if (*FullFileName == NULL) {
@@ -1181,7 +1181,7 @@ FileHandleWriteLine(
   @param[in] Format   the format argument (see printlib for format specifier)
   @param[in] ...      the variable arguments for the format
 
-  @retval EFI_SUCCESS the operation was sucessful
+  @retval EFI_SUCCESS the operation was successful
   @return other       a return value from FileHandleWriteLine
 
   @sa FileHandleWriteLine
@@ -489,7 +489,7 @@ FileHandleFindFirstFile (
 
   //
-  // reset to the begining of the directory
+  // reset to the beginning of the directory
   //
   Status = FileHandleSetPosition(DirHandle, 0);
-- 
1.8.3.1



^ permalink raw reply related	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2016-10-08  1:16 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2016-09-09 20:33 [PATCH] MdePkg: Fix some typing errors Thomas Huth
2016-09-12  1:26 ` Gao, Liming
2016-09-12  8:36   ` Thomas Huth
2016-09-12  9:09 ` Gao, Liming
2016-10-08  1:16   ` Kinney, Michael D

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox